@@ -122,30 +122,31 @@ openstack_projects = [
 # used only to denote unmaintained branches, and it is not intended to be used for
 # replacing anything in documentation.
 
-KOLLA_OPENSTACK_RELEASE = openstackdocstheme.ext._get_series_name()
+OPENSTACK_RELEASE = openstackdocstheme.ext._get_series_name()
 
 KOLLA_OPENSTACK_RELEASE_UNMAINTAINED = [
-    'yoga',
-    'zed',
+    '2023.1',
 ]
 
-if KOLLA_OPENSTACK_RELEASE == 'latest':
+if OPENSTACK_RELEASE == 'latest':
     KOLLA_OPENSTACK_RELEASE = 'master'
     KOLLA_BRANCH_NAME = 'master'
     TESTED_RUNTIMES_GOVERNANCE_URL = 'https://governance.openstack.org/tc/reference/runtimes/'
-elif KOLLA_OPENSTACK_RELEASE in KOLLA_OPENSTACK_RELEASE_UNMAINTAINED:
+elif OPENSTACK_RELEASE in KOLLA_OPENSTACK_RELEASE_UNMAINTAINED:
+    KOLLA_OPENSTACK_RELEASE = OPENSTACK_RELEASE
     KOLLA_BRANCH_NAME = 'unmaintained/{}'.format(KOLLA_OPENSTACK_RELEASE)
     TESTED_RUNTIMES_GOVERNANCE_URL =\
         'https://governance.openstack.org/tc/reference/runtimes/{}.html'.format(KOLLA_OPENSTACK_RELEASE)
 else:
+    KOLLA_OPENSTACK_RELEASE = OPENSTACK_RELEASE
     KOLLA_BRANCH_NAME = 'stable/{}'.format(KOLLA_OPENSTACK_RELEASE)
     TESTED_RUNTIMES_GOVERNANCE_URL =\
         'https://governance.openstack.org/tc/reference/runtimes/{}.html'.format(KOLLA_OPENSTACK_RELEASE)
 
-ANSIBLE_CORE_VERSION_MIN = '2.15'
-ANSIBLE_CORE_VERSION_MAX = '2.16'
-ANSIBLE_VERSION_MIN = '8'
-ANSIBLE_VERSION_MAX = '9'
+ANSIBLE_CORE_VERSION_MIN = '2.16'
+ANSIBLE_CORE_VERSION_MAX = '2.17'
+ANSIBLE_VERSION_MIN = '9'
+ANSIBLE_VERSION_MAX = '10'
 
 GLOBAL_VARIABLE_MAP = {
     '|ANSIBLE_CORE_VERSION_MIN|': ANSIBLE_CORE_VERSION_MIN,
@@ -155,6 +156,7 @@ GLOBAL_VARIABLE_MAP = {
     '|KOLLA_OPENSTACK_RELEASE|': KOLLA_OPENSTACK_RELEASE,
     '|KOLLA_BRANCH_NAME|': KOLLA_BRANCH_NAME,
     '|KOLLA_BRANCH_NAME_DASHED|': KOLLA_BRANCH_NAME.replace('/', '-'),
+    '|OPENSTACK_RELEASE|': OPENSTACK_RELEASE,
     '|TESTED_RUNTIMES_GOVERNANCE_URL|': TESTED_RUNTIMES_GOVERNANCE_URL,
 }
 
